.. _sage_package.sphinx:

A Sphinx extension for writing SageMath-style documentation
===========================================================

.. automodule:: sage_package.sphinx
   :members:
   :undoc-members:
   :show-inheritance:
